@@ -14,13 +14,13 @@
 #include "AppleOnboardAudio.h"
 
 enum{
-    kBasePowerObject,     	//basic mute 
-    kProj6PowerObject = 6,	// for WallStreet
-    kProj7PowerObject,	  	// for Screamer based G4 tower and iMac DVs
-    kProj8PowerObject,	  	// for iBook with Clamshell
-    kProj10PowerObject  =10,    // for Pismo and Titanium
-    kProj14PowerObject =14,	// for Texas 3001 based Tower
-    kProj16PowerObject =16  	// for dual USB iBook
+    kBasePowerObject,     			// basic mute 
+    kProj6PowerObject = 6,			// for PowerBook G3
+    kProj7PowerObject,	  			// for Screamer based G4 tower and iMac DVs
+    kProj8PowerObject,	  			// for iBook with Clamshell
+    kProj10PowerObject = 10,    	// for Pismo and Titanium
+    kProj14PowerObject = 14,		// for Texas 3001 based Tower
+    kProj16PowerObject = 16  		// for dual USB iBook
 };
 
 #pragma mark -
@@ -45,11 +45,11 @@ protected:
     AppleOnboardAudio *audioPluginRef;
     short 	hardwareType;
     OSArray *OutputPortMuteStates;
-    bool     singleMuteState;
+//    bool     singleMuteState;
 }; 
 
 
-    //For FW PB and Titanium
+// For FW PB and PowerBook G4
 #pragma mark -
 class AudioProj10PowerObject : public AudioPowerObject {
      OSDeclareDefaultStructors(AudioProj10PowerObject);
@@ -69,14 +69,14 @@ private:
         kTime10ms = durationMillisecond * 10,	// a delay of 10 ms is required after 
                                                 //starting clocks before doing a recalibrate
         kDefaultPowerObjectReg	= 0x80800000,	// default base address
-        kPowerObjectOffset	= 0x0000006F,	// offset to GPIO5 register
-        kPowerObjectMask	= 0x02,		// determine if PWD is high or low
-        kPowerOn		= 0x05,		// sound power enable
-        kPowerOff		= 0x04		// sound power disable
+        kPowerObjectOffset	= 0x0000006F,		// offset to GPIO5 register
+        kPowerObjectMask	= 0x02,				// determine if PWD is high or low
+        kPowerOn		= 0x05,					// sound power enable
+        kPowerOff		= 0x04					// sound power disable
     };
 };
     
-    //For WallStreet
+// For PowerBook G3
 #pragma mark -
 class AudioProj6PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj6PowerObject);
@@ -96,7 +96,7 @@ private:
     enum {
         durationMillisecond = 1,
         kTime10ms =	durationMillisecond * 10,   // a delay of 10 ms is required after 
-                                                    //starting clocks before doing a recalibrate
+												// starting clocks before doing a recalibrate
         kDefaultPowerObjectReg	= 0xF3000000,	// default base address
         kPowerObjectOffset		= 0x00000038,	// offset to feature Object register
         kPowerObjectMask		= 0x00003000,	// enable sound clock and power, big endian
@@ -114,7 +114,7 @@ private:
     };
 };
 
-    //For B&W G3 (Yosemite)
+// For B&W G3
 #pragma mark -
 class AudioProj4PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj4PowerObject);
@@ -130,18 +130,18 @@ private:
 	
     enum {
         durationMillisecond =1,
-        kTime10ms	= durationMillisecond * 10,	// a delay of 10 ms is required after 
-                                                    //starting clocks before doing a recalibrate
-        kDefaultPowerObjectReg	= 0x80800000,	// default base address
-        kPowerObjectOffset	= 0x00000038,	// offset to feature Object register
-        kPowerObjectMask	= 0x00100000,	// enable sound clock and power, endian swapped
-        kPowerOn		= 0x00100000,	// sound power enable
-        kPowerOff		= 0x00100000,	// sound power disable
-        kPowerYosemite		= 0x00100000	// sound power enable for Yosemite
+        kTime10ms	= durationMillisecond * 10,		// a delay of 10 ms is required after 
+                                                    // starting clocks before doing a recalibrate
+        kDefaultPowerObjectReg	= 0x80800000,		// default base address
+        kPowerObjectOffset	= 0x00000038,			// offset to feature Object register
+        kPowerObjectMask	= 0x00100000,			// enable sound clock and power, endian swapped
+        kPowerOn		= 0x00100000,				// sound power enable
+        kPowerOff		= 0x00100000,				// sound power disable
+        kPowerYosemite		= 0x00100000			// sound power enable for Yosemite
     };
 };
 
-    //for iBooks in Clamshell
+// for iBooks in Clamshell
 #pragma mark -
 class AudioProj8PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj8PowerObject);
@@ -159,7 +159,7 @@ private:
 
 };
 
-    //for Screamer base G4 and iMac DVs
+// for Screamer based G4 and iMac DVs
 #pragma mark -
 class AudioProj7PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj7PowerObject);
@@ -179,21 +179,21 @@ private:
 	
     enum {
         durationMillisecond = 1,
-        kTime10ms = durationMillisecond * 10,	// a delay of 10 ms is required after 
-                                            //starting clocks before doing a recalibrate
-        kTime100ms = durationMillisecond * 100,	// a delay of 100 ms is required to let the 
-                                            //anti-pop circuit do its thing
-        kTime500ms = durationMillisecond * 500,	// a delay of 500 ms is required to let the 
-                                            //anti-pop circuit do its thing
-        kDefaultPowerObjectReg	= 0x80800000,	// default base address
-        kPowerObjectOffset	= 0x0000006F,	// offset to GPIO5 register
-        kPowerObjectMask	= 0x02,		// determine if PWD is high or low
-        kPowerOn		= 0x05,		// sound power enable
-        kPowerOff		= 0x04		// sound power disable
+        kTime10ms = durationMillisecond * 10,		// a delay of 10 ms is required after 
+													// starting clocks before doing a recalibrate
+        kTime100ms = durationMillisecond * 100,		// a delay of 100 ms is required to let the 
+													// anti-pop circuit do its thing
+        kTime500ms = durationMillisecond * 500,		// a delay of 500 ms is required to let the 
+													// anti-pop circuit do its thing
+        kDefaultPowerObjectReg	= 0x80800000,		// default base address
+        kPowerObjectOffset	= 0x0000006F,			// offset to GPIO5 register
+        kPowerObjectMask	= 0x02,					// determine if PWD is high or low
+        kPowerOn		= 0x05,						// sound power enable
+        kPowerOff		= 0x04						// sound power disable
     };
 };
     
-    //for Texas3001 Tower
+// for Texas3001 Tower
 #pragma mark -
 class AudioProj14PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj14PowerObject);
@@ -211,7 +211,7 @@ private:
 	bool init(AppleOnboardAudio *pluginRef);
 };
     
-    //for iBook dual USB
+// for iBook dual USB
 #pragma mark -
 class AudioProj16PowerObject : public AudioPowerObject {
     OSDeclareDefaultStructors(AudioProj16PowerObject);
